summaryrefslogtreecommitdiffstats
path: root/misc/scripts/copyright_headers.py
diff options
context:
space:
mode:
Diffstat (limited to 'misc/scripts/copyright_headers.py')
-rwxr-xr-xmisc/scripts/copyright_headers.py10
1 files changed, 6 insertions, 4 deletions
diff --git a/misc/scripts/copyright_headers.py b/misc/scripts/copyright_headers.py
index 2b1201b..2ffa01b 100755
--- a/misc/scripts/copyright_headers.py
+++ b/misc/scripts/copyright_headers.py
@@ -9,9 +9,11 @@ header = """\
/* $filename */
/**************************************************************************/
/* This file is part of: */
-/* GODOT ENGINE */
-/* https://godotengine.org */
+/* REDOT ENGINE */
+/* https://redotengine.org */
/**************************************************************************/
+/* Copyright (c) 2024-present Redot Engine contributors */
+/* (see REDOT_AUTHORS.md) */
/* Copyright (c) 2014-present Godot Engine contributors (see AUTHORS.md). */
/* Copyright (c) 2007-2014 Juan Linietsky, Ariel Manzur. */
/* */
@@ -76,8 +78,8 @@ for f in sys.argv[1:]:
while line.strip() == "" and line != "": # Skip empty lines at the top
line = fileread.readline()
- if line.find("/**********") == -1: # Godot header starts this way
- # Maybe starting with a non-Godot comment, abort header magic
+ if line.find("/**********") == -1: # Redot header starts this way
+ # Maybe starting with a non-Redot comment, abort header magic
header_done = True
while not header_done: # Handle header now